@@ -75,7 +75,7 @@ class KARPClient(object):
     async def _read(self) -> None:
         while True:
             try:
-                responses: bytes = await self.reader.read(100000)
+                responses: bytes = await self.reader.readuntil(b"\n")
             except BrokenPipeError:
                 break
             if not responses:
